@@ -6,7 +6,7 @@
    Backend for Asymptote files
    Contributed by: John Bowman
 
-   Copyright (C) 1993 - 2013 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2014 Wolfgang Glunz, wglunz35_AT_pstoedit.net
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #include "drvbase.h"
 
 
-#ifdef HAVESTL
+#ifdef HAVE_STL
 #include <string>        // C++ string class
 #include <list>
 #else
@@ -52,7 +52,7 @@ public:
   void show_text(const TextInfo & textInfo);
   void show_image(const PSImage & imageinfo);
   
-  void ClipPath(cliptype);
+  virtual void ClipPath(cliptype);
   void Save();
   void Restore();
 
