@@ -2,7 +2,7 @@
    drvPCB1.cpp : Hans-Jrgen Jahn    (Version 1.0  10.08.02)
    this code is derived from drvSAMPL.cpp, see text below
 
-   Copyright (C) 1993 - 2013 Wolfgang Glunz, wglunz35_AT_pstoedit.net
+   Copyright (C) 1993 - 2014 Wolfgang Glunz, wglunz35_AT_pstoedit.net
    (for the skeleton and the rest of pstoedit)
 
     This program is free software; you can redistribute it and/or modify
@@ -128,14 +128,14 @@ void drvPCB1::close_page()
 
 void drvPCB1::show_text(const TextInfo & textinfo)
 {
-	pcberrf << "Text String : " << textinfo.thetext.value() << endl;
+	pcberrf << "Text String : " << textinfo.thetext.c_str() << endl;
 	pcberrf << '\t' << "X " << textinfo.x << " Y " << textinfo.y << endl;
 	pcberrf << '\t' << "X_END " << textinfo.x_end << " Y_END " << textinfo.y_end << endl;
-	pcberrf << '\t' << "currentFontName: " <<  textinfo.currentFontName.value() << endl;
+	pcberrf << '\t' << "currentFontName: " <<  textinfo.currentFontName.c_str() << endl;
 	pcberrf << '\t' << "is_non_standard_font: " <<  textinfo.is_non_standard_font << endl;
-	pcberrf << '\t' << "currentFontFamilyName: " << textinfo.currentFontFamilyName.value() << endl;
-	pcberrf << '\t' << "currentFontFullName: " << textinfo.currentFontFullName.value() << endl;
-	pcberrf << '\t' << "currentFontWeight: " << textinfo.currentFontWeight.value() << endl;
+	pcberrf << '\t' << "currentFontFamilyName: " << textinfo.currentFontFamilyName.c_str() << endl;
+	pcberrf << '\t' << "currentFontFullName: " << textinfo.currentFontFullName.c_str() << endl;
+	pcberrf << '\t' << "currentFontWeight: " << textinfo.currentFontWeight.c_str() << endl;
 	pcberrf << '\t' << "currentFontSize: " << textinfo.currentFontSize << endl;
 	pcberrf << '\t' << "currentFontAngle: " << textinfo.currentFontAngle << endl;
 	pcberrf << '\t' << "currentR: " << textinfo.currentR << endl;
